@@ -49,6 +49,9 @@ define!({
         Ratio(Ratio),
         UnicodeRange(UnicodeRange),
         Color(Color),
+        AlphaValue(AlphaValue),
+        Hue(Hue),
+        CmykComponent(CmykComponent),
         Delimiter(Delimiter),
 
         CalcSum(CalcSum),
@@ -155,6 +158,21 @@ define!({
         pub raw: JsWord,
     }
 
+    pub enum AlphaValue {
+        Number(Number),
+        Percentage(Percentage),
+    }
+
+    pub enum Hue {
+        Number(Number),
+        Angle(Angle),
+    }
+
+    pub enum CmykComponent {
+        Number(Number),
+        Percentage(Percentage),
+    }
+
     pub enum Dimension {
         Length(Length),
         Angle(Angle),
